==> boks_logger-0.1.1.tar.gz: lib/src/logger.dart <==
// logger.dart - Logging with colours and defined severity

import 'dart:io';

import "package:ansicolor/ansicolor.dart";
import "package:intl/intl.dart";

enum Severity { Debug, Success, Info, Warning, Error, Fatal }

final DateFormat timeFormat = DateFormat.Hms();

// default logger, use non american name for log file
final Logger logger = Logger();

class Logger {
	File logFile;
	DateFormat timeFormatLogFile;

	AnsiPen infoColor = AnsiPen()..blue();
	AnsiPen debugColor = AnsiPen()..white();
	AnsiPen successColor = AnsiPen()..green();
	AnsiPen warningColor = AnsiPen()..yellow();
	AnsiPen errorColor = AnsiPen()..red();
	AnsiPen fatalColor = AnsiPen()..xterm(196); // redder red, probably there is a better way to do it lol

	Logger({bool useAmerican: false}) {
		if(useAmerican) timeFormatLogFile = DateFormat("d-M-y");
		else timeFormatLogFile = DateFormat("M-d-y");
		
		logFile = File("logs/${timeFormatLogFile.format(DateTime.now())}.log");
		logFile.create(recursive: true);
		
		info("Log initialized");
	}


	Severity severityLevel = Severity.Debug;

	void debug(String message) => _log(message, Severity.Debug, debugColor);

	void info(String message) => _log(message, Severity.Info, infoColor);

	void success(String message) => _log(message, Severity.Success, successColor);

	void warning(String message) => _log(message, Severity.Warning, warningColor);

	void error(String message) => _log(message, Severity.Error, errorColor);

	void fatal(String message, [Exception exception]) => _throwError(message, exception);

	void _throwError(String message, [Exception exception]) {
		_log(message, Severity.Fatal, fatalColor);
		if(exception != null) throw exception;
		else throw Exception();
	}

	void _log(String message, Severity severity, AnsiPen pen, { bool logToFile: true }) async {
		final String time = timeFormat.format(DateTime.now());
		final String severityName = severity.toString().toUpperCase().split(".")[1];

		String completeMessage = "<$time> [$severityName] $message";

		print(pen(completeMessage));

		if(logToFile) {
			_writeToFile(completeMessage);
		}
	}

	void _writeToFile(String message) async => logFile.writeAsStringSync("$message\n", mode: FileMode.append);
}

==> boks_logger-0.2.1.tar.gz: lib/src/logger.dart <==
// logger.dart - Logging with colours and defined severity

import 'dart:io';

import "package:ansicolor/ansicolor.dart";
import "package:intl/intl.dart";

enum Severity { Debug, Success, Info, Warning, Error, Fatal }

final DateFormat timeFormat = DateFormat.Hms();

/// Default logger, uses non american name for log file
final Logger logger = Logger();

/// Logger class, instantiate and use
class Logger {
	File _logFile;

	Severity currentSeverity = Severity.Debug;
	bool logToFile = true;

	AnsiPen infoColor = AnsiPen()..blue();
	AnsiPen debugColor = AnsiPen()..white();
	AnsiPen successColor = AnsiPen()..green();
	AnsiPen warningColor = AnsiPen()..yellow();
	AnsiPen errorColor = AnsiPen()..red();
	AnsiPen fatalColor = AnsiPen()..xterm(196); // redder red, probably there is a better way to do it lol

	Logger({bool useAmerican: false}) {
		DateFormat timeFormatLogFile;
		if(useAmerican) timeFormatLogFile = DateFormat("d-M-y");
		else timeFormatLogFile = DateFormat("M-d-y");
		
		_logFile = File("logs/${timeFormatLogFile.format(DateTime.now())}.log");
		_logFile.create(recursive: true);
		
		info("Log initialized");
	}


	Severity severityLevel = Severity.Debug;

	void debug(String message) => _log(message, Severity.Debug, debugColor);

	void info(String message) => _log(message, Severity.Info, infoColor);

	void success(String message) => _log(message, Severity.Success, successColor);

	void warning(String message) => _log(message, Severity.Warning, warningColor);

	void error(String message) => _log(message, Severity.Error, errorColor);

	void fatal(String message, [Exception exception]) => _throwError(message, exception);

	void _throwError(String message, [Exception exception]) {
		_log(message, Severity.Fatal, fatalColor);
		if(exception != null) throw exception;
		else throw Exception();
	}

	void _log(String message, Severity severity, AnsiPen pen) async {
		if(currentSeverity.index > severity.index) return;
		final String time = timeFormat.format(DateTime.now());
		final String severityName = severity.toString().toUpperCase().split(".")[1];

		String completeMessage = "<$time> [$severityName] $message";

		print(pen(completeMessage));

		if(logToFile) {
			_writeToFile(completeMessage);
		}
	}

	void _writeToFile(String message) async => _logFile.writeAsStringSync("$message\n", mode: FileMode.append);
}
